@@ -54,14 +54,14 @@ bool BirthdaysConfigAgentWidget::save() const
 
 QSize BirthdaysConfigAgentWidget::restoreDialogSize() const
 {
-    const auto group = config()->group(QLatin1String(myConfigGroupName));
+    const auto group = config()->group(QLatin1StringView(myConfigGroupName));
     const QSize size = group.readEntry("Size", QSize(600, 400));
     return size;
 }
 
 void BirthdaysConfigAgentWidget::saveDialogSize(const QSize &size)
 {
-    auto group = config()->group(QLatin1String(myConfigGroupName));
+    auto group = config()->group(QLatin1StringView(myConfigGroupName));
     group.writeEntry("Size", size);
 }
 
