@@ -221,6 +221,8 @@ POP3Protocol::Resp POP3Protocol::getResponse(char *r_buf, unsigned int r_len)
 
 bool POP3Protocol::sendCommand(const QByteArray &cmd)
 {
+    Q_ASSERT(QThread::currentThread() != qApp->thread());
+
     /*
      *   From rfc1939:
      *
@@ -309,6 +311,8 @@ static QString saslAuthTypeString(const Settings &settings)
 
 void POP3Protocol::closeConnection()
 {
+    Q_ASSERT(QThread::currentThread() != qApp->thread());
+
     if (!mConnected) {
         return;
     }
@@ -712,10 +716,6 @@ Result POP3Protocol::get(const QString &_commandString)
     // /uidl          UIDL      List message UIDs
     // /remove/#1     DELE #1   Mark a message for deletion
     // /download/#1   RETR #1   Get message header and body
-    // /list/#1       LIST #1   Get size of a message
-    // /uid/#1        UIDL #1   Get UID of a message
-    // /quit          QUIT      Send QUIT, close connection
-    // /headers/#1    TOP #1    Get header of message
     //
     // Notes:
     // Sizes are in bytes.
@@ -729,8 +729,7 @@ Result POP3Protocol::get(const QString &_commandString)
     char destbuf[MAX_PACKET_LEN];
     const int maxCommands = mSettings.pipelining() ? MAX_COMMANDS : 1;
 
-    if (((commandString.indexOf(QLatin1Char('/')) == -1) && (commandString != QLatin1StringView("index")) && (commandString != QLatin1StringView("uidl"))
-         && (commandString != QLatin1StringView("quit")))) {
+    if (commandString.indexOf(QLatin1Char('/')) == -1 && commandString != QLatin1StringView("index") && commandString != QLatin1StringView("uidl")) {
         return Result::fail(ERR_INTERNAL, i18n("Internal error: missing argument for command %1", commandString));
     }
 
@@ -782,7 +781,7 @@ Result POP3Protocol::get(const QString &_commandString)
             getResponse(buf, sizeof(buf) - 1);
             activeCommands--;
         }
-    } else if (cmd == QLatin1StringView("download") || cmd == QLatin1StringView("headers")) {
+    } else if (cmd == QLatin1StringView("download")) {
         const QStringList waitingCommands = path.split(QLatin1Char(','), Qt::SkipEmptyParts);
         if (waitingCommands.isEmpty()) {
             qCDebug(POP3_LOG) << "tried to request" << cmd << "for" << path << "with no specific item to get";
@@ -795,9 +794,7 @@ Result POP3Protocol::get(const QString &_commandString)
         QStringList::ConstIterator it = waitingCommands.begin();
         while (it != waitingCommands.end() || activeCommands > 0) {
             while (activeCommands < maxCommands && it != waitingCommands.end()) {
-                sendCommand(QString((cmd == QLatin1StringView("headers")) ? QString(QLatin1StringView("TOP ") + *it + QLatin1StringView(" 0"))
-                                                                          : QString(QLatin1StringView("RETR ") + *it))
-                                .toLatin1());
+                sendCommand(QString(QLatin1StringView("RETR ") + *it).toLatin1());
                 activeCommands++;
                 it++;
             }
@@ -883,35 +880,6 @@ Result POP3Protocol::get(const QString &_commandString)
             }
         }
         qCDebug(POP3_LOG) << "Finishing up";
-    } else if ((cmd == QLatin1StringView("uid")) || (cmd == QLatin1StringView("list"))) {
-        bool ok = true;
-        (void)path.toInt(&ok);
-        if (!ok) {
-            return Result::fail(ERR_INTERNAL, i18n("Internal error, number expected: %1", path));
-        }
-
-        QString commandStr;
-        if (cmd == QLatin1StringView("uid")) {
-            commandStr = QLatin1StringView("UIDL ") + path;
-        } else {
-            commandStr = QLatin1StringView("LIST ") + path;
-        }
-
-        memset(buf, 0, sizeof(buf));
-        if (command(commandStr.toLatin1(), buf, sizeof(buf) - 1) == Ok) {
-            const int len = strlen(buf);
-            // totalSize(len);
-            Q_EMIT data(QByteArray(buf, len));
-            // processedSize(len);
-            qCDebug(POP3_LOG) << buf;
-            qCDebug(POP3_LOG) << "Finishing up uid";
-        } else {
-            closeConnection();
-            return Result::fail(ERR_PROTOCOL, i18n("Unexpected response from POP3 server."));
-        }
-    } else if (cmd == QLatin1StringView("quit")) {
-        qCDebug(POP3_LOG) << "Issued QUIT";
-        closeConnection();
     }
     return Result::pass();
 }
